pub enum CreateSessionMode {
Regular,
Draft,
Orchestrator,
OrchestrationChild {
task_id: i64,
},
OrchestrationResearch {
task_id: i64,
},
Stacked {
parent_session_id: SessionId,
},
}Expand description
Creation strategy for a new session.
Variants
Regular
Creates a regular root session with an eagerly materialized worktree.
Draft
Creates a root draft whose worktree is materialized on first send.
Orchestrator
Creates a controller session that plans and supervises worker sessions.
OrchestrationChild
Creates one worker owned by a persisted orchestration task.
OrchestrationResearch
Creates one temporary read-only researcher owned by an orchestration task.
Stacked
Creates a one-level draft stacked on an existing parent session.