pub enum IntegrationApproach {
LocalMerge,
ReviewRequest,
}Expand description
User-selected destination for verified orchestration task branches.
Variants
LocalMerge
Merge each verified child branch into the campaign base locally.
ReviewRequest
Publish each verified child branch as a forge review request.