pub struct AnswerQuestionsRequest {
pub answers: Vec<QuestionAnswer>,
}Expand description
Structured input for resuming one session from clarification questions.
Fields
answers: Vec<QuestionAnswer>Ordered question and answer pairs for the current question set.