pub struct SessionMessage {
pub content: String,
pub kind: SessionMessageKind,
pub position: i64,
}Expand description
One persisted transcript message for a session.
Fields
content: StringCanonical transcript text for this message.
kind: SessionMessageKindDurable message category.
position: i64Monotonic position within the owning session transcript.
Implementations
Sourceimpl SessionMessage
impl SessionMessage
Sourcepub fn new(
position: i64,
kind: SessionMessageKind,
content: impl Into<String>,
) -> Self
pub fn new( position: i64, kind: SessionMessageKind, content: impl Into<String>, ) -> Self
Creates one transcript message at a stable transcript position.
Sourcepub fn conversation(
position: i64,
kind: SessionMessageKind,
content: impl AsRef<str>,
) -> Self
pub fn conversation( position: i64, kind: SessionMessageKind, content: impl AsRef<str>, ) -> Self
Creates one raw user or assistant message using kind-specific storage normalization.